#
# spec file for package ocaml-lablgl
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2011 Andrew Psaltis <ampsaltis at gmail.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ocaml-lablgl
Version:        1.05
Release:        8.25
%{?ocaml_preserve_bytecode}

Summary:        LablGL is an OpenGL interface for Objective Caml
License:        BSD-3-Clause
Group:          Development/Languages/OCaml

Url:            https://forge.ocamlcore.org/projects/lablgl/
Source0:        lablgl-%{version}.tar.xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  ocaml
BuildRequires:  ocaml-camlp4-devel
BuildRequires:  ocaml-rpm-macros >= 20200220
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)

%description
LablGL is is an Objective Caml interface to OpenGL. Support is
included for use inside LablTk, and LablGTK also includes specific
support for LablGL.  It can be used either with proprietary OpenGL
implementations (SGI, Digital Unix, Solaris...), with XFree86 GLX
extension, or with open-source Mesa.


%package        devel
Summary:        Development files for %{name}
Group:          Development/Languages/OCaml
Requires:       %{name} = %{version}
Requires:       ocaml-labltk-devel

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.


%prep
%setup -q -n lablgl-%{version}

tee Makefile.config <<EOF
%if 0%{?ocaml_native_compiler}
CAMLC = ocamlc.opt
CAMLOPT = ocamlopt.opt
%else
CAMLC = ocamlc
CAMLOPT = ocamlc
%endif
BINDIR = %{_bindir}
XINCLUDES = $(pkg-config --cflags x11)
XLIBS = $(pkg-config --libs x11)
GLINCLUDES = $(pkg-config --libs gl glu)
GLLIBS = $(pkg-config --libs gl glu)
RANLIB = :
LIBDIR = %{ocaml_standard_library}
DLLDIR = %{ocaml_standard_library}/stublibs
INSTALLDIR = %{ocaml_standard_library}/lablGL
COPTS = $RPM_OPT_FLAGS
EOF

%build
make lib
%if 0%{?ocaml_native_compiler}
make libopt
%endif

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{_bindir}
mkdir -p $RPM_BUILD_ROOT%{ocaml_standard_library}/lablGL
mkdir -p $RPM_BUILD_ROOT%{ocaml_standard_library}/stublibs
make INSTALLDIR=$RPM_BUILD_ROOT%{ocaml_standard_library}/lablGL \
    DLLDIR=$RPM_BUILD_ROOT%{ocaml_standard_library}/stublibs \
    BINDIR=$RPM_BUILD_ROOT%{_bindir} \
    install

# Make and install a META file.
cat <<EOM >META
version="%{version}"
directory="+lablgl"
archive(byte) = "lablgl.cma"
archive(native) = "lablgl.cmxa"

package "glut" (
  requires = "lablgl"
  archive(byte) = "lablglut.cma"
  archive(native) = "lablglut.cmxa"
)
EOM
cp META $RPM_BUILD_ROOT%{ocaml_standard_library}/lablGL

# Remove unnecessary *.ml files (ones which have a *.mli).
pushd $RPM_BUILD_ROOT%{ocaml_standard_library}/lablGL
rm -fv build.ml
for f in *.ml; do \
  b=`basename $f .ml`; \
  if [ -f "$b.mli" ]; then \
    rm $f; \
  fi; \
done
popd
#
%ocaml_create_file_list

%files -f %{name}.files

%files devel -f %{name}.files.devel
%doc CHANGES README

%changelog
* Thu Feb 20 2020 ohering@suse.de
- Require current ocaml-rpm-macros
- Fix build failure after recent X11 changes in SLE15
* Tue Jul 25 2017 ohering@suse.de
- Use Group: Development/Languages/OCaml
* Mon Jul 17 2017 ohering@suse.de
- Wrap specfile conditionals to fix quilt setup
* Mon Jul 17 2017 ohering@suse.de
- Remove autodeps for pre openSUSE 12.1 releases
* Tue Nov 10 2015 ohering@suse.de
- Add hardcoded Provides for pre 12.1 repos
* Thu Nov  7 2013 tom.mbrt@googlemail.com
- update to 1.05 fixes build on openSUSE 13.1
* Mon Jun  3 2013 ohering@suse.de
- Recompress with xz
* Wed Jan 16 2013 ohering@suse.de
- disable also /usr/lib/rpm/find-debuginfo.sh
* Mon Jan 14 2013 ohering@suse.de
- disable strip, it destroys bytecode binaries
* Mon Jan 14 2013 ohering@suse.de
- change Requires: version-release to just Requires: version
* Fri Jun 17 2011 ampsaltis@gmail.com
- Add this file
- Use ocaml-camlp4-devel instead of camlp4
